==> openshift-model-machine-6.7.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineStatusBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineStatusBuilder extends MachineStatusFluentImpl<MachineStatusBuilder> implements VisitableBuilder<MachineStatus,MachineStatusBuilder>{
  public MachineStatusBuilder() {
    this(false);
  }
  public MachineStatusBuilder(Boolean validationEnabled) {
    this(new MachineStatus(), validationEnabled);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineStatus(), validationEnabled);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent,MachineStatus instance) {
    this(fluent, instance, false);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent,MachineStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAddresses(instance.getAddresses());
      fluent.withConditions(instance.getConditions());
      fluent.withErrorMessage(instance.getErrorMessage());
      fluent.withErrorReason(instance.getErrorReason());
      fluent.withLastOperation(instance.getLastOperation());
      fluent.withLastUpdated(instance.getLastUpdated());
      fluent.withNodeRef(instance.getNodeRef());
      fluent.withPhase(instance.getPhase());
      fluent.withProviderStatus(instance.getProviderStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachineStatusBuilder(MachineStatus instance) {
    this(instance,false);
  }
  public MachineStatusBuilder(MachineStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAddresses(instance.getAddresses());
      this.withConditions(instance.getConditions());
      this.withErrorMessage(instance.getErrorMessage());
      this.withErrorReason(instance.getErrorReason());
      this.withLastOperation(instance.getLastOperation());
      this.withLastUpdated(instance.getLastUpdated());
      this.withNodeRef(instance.getNodeRef());
      this.withPhase(instance.getPhase());
      this.withProviderStatus(instance.getProviderStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachineStatusFluent<?> fluent;
  Boolean validationEnabled;
  public MachineStatus build() {
    MachineStatus buildable = new MachineStatus(fluent.getAddresses(),fluent.getConditions(),fluent.getErrorMessage(),fluent.getErrorReason(),fluent.getLastOperation(),fluent.getLastUpdated(),fluent.getNodeRef(),fluent.getPhase(),fluent.getProviderStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-machine-6.8.0-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineStatusBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineStatusBuilder extends MachineStatusFluent<MachineStatusBuilder> implements VisitableBuilder<MachineStatus,MachineStatusBuilder>{
  public MachineStatusBuilder() {
    this(false);
  }
  public MachineStatusBuilder(Boolean validationEnabled) {
    this(new MachineStatus(), validationEnabled);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineStatus(), validationEnabled);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent,MachineStatus instance) {
    this(fluent, instance, false);
  }
  public MachineStatusBuilder(MachineStatusFluent<?> fluent,MachineStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MachineStatus());

    if (instance != null) {
      fluent.withAddresses(instance.getAddresses());
      fluent.withConditions(instance.getConditions());
      fluent.withErrorMessage(instance.getErrorMessage());
      fluent.withErrorReason(instance.getErrorReason());
      fluent.withLastOperation(instance.getLastOperation());
      fluent.withLastUpdated(instance.getLastUpdated());
      fluent.withNodeRef(instance.getNodeRef());
      fluent.withPhase(instance.getPhase());
      fluent.withProviderStatus(instance.getProviderStatus());
      fluent.withAddresses(instance.getAddresses());
      fluent.withConditions(instance.getConditions());
      fluent.withErrorMessage(instance.getErrorMessage());
      fluent.withErrorReason(instance.getErrorReason());
      fluent.withLastOperation(instance.getLastOperation());
      fluent.withLastUpdated(instance.getLastUpdated());
      fluent.withNodeRef(instance.getNodeRef());
      fluent.withPhase(instance.getPhase());
      fluent.withProviderStatus(instance.getProviderStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachineStatusBuilder(MachineStatus instance) {
    this(instance,false);
  }
  public MachineStatusBuilder(MachineStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MachineStatus());

    if (instance != null) {
      this.withAddresses(instance.getAddresses());
      this.withConditions(instance.getConditions());
      this.withErrorMessage(instance.getErrorMessage());
      this.withErrorReason(instance.getErrorReason());
      this.withLastOperation(instance.getLastOperation());
      this.withLastUpdated(instance.getLastUpdated());
      this.withNodeRef(instance.getNodeRef());
      this.withPhase(instance.getPhase());
      this.withProviderStatus(instance.getProviderStatus());
      this.withAddresses(instance.getAddresses());
      this.withConditions(instance.getConditions());
      this.withErrorMessage(instance.getErrorMessage());
      this.withErrorReason(instance.getErrorReason());
      this.withLastOperation(instance.getLastOperation());
      this.withLastUpdated(instance.getLastUpdated());
      this.withNodeRef(instance.getNodeRef());
      this.withPhase(instance.getPhase());
      this.withProviderStatus(instance.getProviderStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachineStatusFluent<?> fluent;
  Boolean validationEnabled;
  public MachineStatus build() {
    MachineStatus buildable = new MachineStatus(fluent.getAddresses(),fluent.buildConditions(),fluent.getErrorMessage(),fluent.getErrorReason(),fluent.buildLastOperation(),fluent.getLastUpdated(),fluent.buildNodeRef(),fluent.getPhase(),fluent.getProviderStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
